package tests

import (
	"testing"

	"github.com/stretchr/testify/assert"
)

func TestCreateTeam(t *testing.T) {
	client, close := getClient()
	defer close()

	createTeamResp, err := createTeam(client, "Тестовая команда")
	assert.Nil(t, err, "запрос отправлен успешно")
	assert.Equal(t, len(createTeamResp.Teams), 1, "количество команд равно 1")
	assert.Equal(t, createTeamResp.Teams[0].Name, "Тестовая команда")

	getTeamsResp, err := getTeams(client)
	assert.Nil(t, err, "запрос отправлен успешно")
	assert.Equal(t, len(getTeamsResp.Teams), 1, "количество команд равно 1")
	assert.Equal(t, getTeamsResp.Teams[0].Name, "Тестовая команда")

	deleteTeams(t)
}

func TestCreateTeamWithEmptyName(t *testing.T) {
	client, close := getClient()
	defer close()

	_, err := createTeam(client, "")
	assert.NotNil(t, err, "запрос не удался")

	deleteTeams(t)
}

func TestCreateTwoTeam(t *testing.T) {
	client, close := getClient()
	defer close()

	_, err := createTeam(client, "Тестовая команда 1")
	assert.Nil(t, err, "запрос отправлен успешно")

	_, err = createTeam(client, "Тестовая команда 2")
	assert.Nil(t, err, "запрос отправлен успешно")

	getTeamsResp, err := getTeams(client)
	assert.Nil(t, err, "запрос отправлен успешно")
	assert.Equal(t, len(getTeamsResp.Teams), 2, "количество команд равно 2")
	assert.Equal(t, getTeamsResp.Teams[0].Name, "Тестовая команда 1")
	assert.Equal(t, getTeamsResp.Teams[1].Name, "Тестовая команда 2")

	deleteTeams(t)
}

func TestCreateTwoEqTeam(t *testing.T) {
	client, close := getClient()
	defer close()

	_, err := createTeam(client, "Тестовая команда")
	assert.Nil(t, err, "запрос отправлен успешно")

	_, err = createTeam(client, "Тестовая команда")
	assert.NotNil(t, err, "запрос не удался")

	deleteTeams(t)
}

func TestCreateTwoBadTeam(t *testing.T) {
	client, close := getClient()
	defer close()

	_, err := createTeam(client, "Тестовая команда")
	assert.Nil(t, err, "запрос отправлен успешно")

	_, err = createTeam(client, "Тестовая команда ")
	assert.NotNil(t, err, "запрос не удался")

	deleteTeams(t)
}
